
/* GENERATED CODE... DO NOT EDIT */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 *
 * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
 */


#include <string.h>

#include "mbim-auth.h"
#include "mbim-message-private.h"
#include "mbim-enum-types.h"
#include "mbim-error-types.h"
#include "mbim-device.h"
#include "mbim-utils.h"

/*****************************************************************************/
/* Message (Query): MBIM Message Auth Aka */

/**
 * mbim_message_auth_aka_query_new:
 * @rand: the 'Rand' field, given as an array of 16 #guint8 values.
 * @autn: the 'Autn' field, given as an array of 16 #guint8 values.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Aka' query command in the 'Auth' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_auth_aka_query_new (
    const guint8 *rand,
    const guint8 *autn,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_AUTH,
                                                 MBIM_CID_AUTH_AKA,
                                                 MBIM_MESSAGE_COMMAND_TYPE_QUERY);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, rand, 16);
    }
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, autn, 16);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message Auth Aka */

/**
 * mbim_message_auth_aka_response_parse:
 * @message: the #MbimMessage.
 * @res: return location for an array of 16 #guint8 values. Do not free the returned value, it is owned by @message.
 * @res_len: return location for a #guint32, or %NULL if the 'ResLen' field is not needed.
 * @integrating_key: return location for an array of 16 #guint8 values. Do not free the returned value, it is owned by @message.
 * @ciphering_key: return location for an array of 16 #guint8 values. Do not free the returned value, it is owned by @message.
 * @auts: return location for an array of 14 #guint8 values. Do not free the returned value, it is owned by @message.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Auts' response command in the 'Auth' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_auth_aka_response_parse (
    const MbimMessage *message,
    const guint8 **res,
    guint32 *res_len,
    const guint8 **integrating_key,
    const guint8 **ciphering_key,
    const guint8 **auts,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'Res' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (res != NULL)
            *res = tmp;
        offset += 16;
    }

    /* Read the 'ResLen' variable */
    {
        if (res_len != NULL)
            *res_len =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    /* Read the 'IntegratingKey' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (integrating_key != NULL)
            *integrating_key = tmp;
        offset += 16;
    }

    /* Read the 'CipheringKey' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (ciphering_key != NULL)
            *ciphering_key = tmp;
        offset += 16;
    }

    /* Read the 'Auts' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (auts != NULL)
            *auts = tmp;
        offset += 14;
    }

    return TRUE;
}

/*****************************************************************************/
/* Message (Query): MBIM Message Auth Akap */

/**
 * mbim_message_auth_akap_query_new:
 * @rand: the 'Rand' field, given as an array of 16 #guint8 values.
 * @autn: the 'Autn' field, given as an array of 16 #guint8 values.
 * @network_name: the 'NetworkName' field, given as a string.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Akap' query command in the 'Auth' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_auth_akap_query_new (
    const guint8 *rand,
    const guint8 *autn,
    const gchar *network_name,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_AUTH,
                                                 MBIM_CID_AUTH_AKAP,
                                                 MBIM_MESSAGE_COMMAND_TYPE_QUERY);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, rand, 16);
    }
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, autn, 16);
    }
    {
        _mbim_message_command_builder_append_string (builder, network_name);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message Auth Akap */

/**
 * mbim_message_auth_akap_response_parse:
 * @message: the #MbimMessage.
 * @res: return location for an array of 16 #guint8 values. Do not free the returned value, it is owned by @message.
 * @res_len: return location for a #guint32, or %NULL if the 'ResLen' field is not needed.
 * @integrating_key: return location for an array of 16 #guint8 values. Do not free the returned value, it is owned by @message.
 * @ciphering_key: return location for an array of 16 #guint8 values. Do not free the returned value, it is owned by @message.
 * @auts: return location for an array of 14 #guint8 values. Do not free the returned value, it is owned by @message.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Auts' response command in the 'Auth' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_auth_akap_response_parse (
    const MbimMessage *message,
    const guint8 **res,
    guint32 *res_len,
    const guint8 **integrating_key,
    const guint8 **ciphering_key,
    const guint8 **auts,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'Res' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (res != NULL)
            *res = tmp;
        offset += 16;
    }

    /* Read the 'ResLen' variable */
    {
        if (res_len != NULL)
            *res_len =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    /* Read the 'IntegratingKey' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (integrating_key != NULL)
            *integrating_key = tmp;
        offset += 16;
    }

    /* Read the 'CipheringKey' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (ciphering_key != NULL)
            *ciphering_key = tmp;
        offset += 16;
    }

    /* Read the 'Auts' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (auts != NULL)
            *auts = tmp;
        offset += 14;
    }

    return TRUE;
}

/*****************************************************************************/
/* Message (Query): MBIM Message Auth Sim */

/**
 * mbim_message_auth_sim_query_new:
 * @rand1: the 'Rand1' field, given as an array of 16 #guint8 values.
 * @rand2: the 'Rand2' field, given as an array of 16 #guint8 values.
 * @rand3: the 'Rand3' field, given as an array of 16 #guint8 values.
 * @n: the 'N' field, given as a #guint32.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Sim' query command in the 'Auth' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_auth_sim_query_new (
    const guint8 *rand1,
    const guint8 *rand2,
    const guint8 *rand3,
    guint32 n,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_AUTH,
                                                 MBIM_CID_AUTH_SIM,
                                                 MBIM_MESSAGE_COMMAND_TYPE_QUERY);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, rand1, 16);
    }
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, rand2, 16);
    }
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, rand3, 16);
    }
    {
        _mbim_message_command_builder_append_guint32 (builder, n);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message Auth Sim */

/**
 * mbim_message_auth_sim_response_parse:
 * @message: the #MbimMessage.
 * @sres1: return location for a #guint32, or %NULL if the 'Sres1' field is not needed.
 * @kc1: return location for a #guint64, or %NULL if the 'Kc1' field is not needed.
 * @sres2: return location for a #guint32, or %NULL if the 'Sres2' field is not needed.
 * @kc2: return location for a #guint64, or %NULL if the 'Kc2' field is not needed.
 * @sres3: return location for a #guint32, or %NULL if the 'Sres3' field is not needed.
 * @kc3: return location for a #guint64, or %NULL if the 'Kc3' field is not needed.
 * @n: return location for a #guint32, or %NULL if the 'N' field is not needed.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'N' response command in the 'Auth' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_auth_sim_response_parse (
    const MbimMessage *message,
    guint32 *sres1,
    guint64 *kc1,
    guint32 *sres2,
    guint64 *kc2,
    guint32 *sres3,
    guint64 *kc3,
    guint32 *n,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'Sres1' variable */
    {
        if (sres1 != NULL)
            *sres1 =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    /* Read the 'Kc1' variable */
    {
        if (kc1 != NULL)
            *kc1 =  _mbim_message_read_guint64 (message, offset);
        offset += 8;
    }

    /* Read the 'Sres2' variable */
    {
        if (sres2 != NULL)
            *sres2 =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    /* Read the 'Kc2' variable */
    {
        if (kc2 != NULL)
            *kc2 =  _mbim_message_read_guint64 (message, offset);
        offset += 8;
    }

    /* Read the 'Sres3' variable */
    {
        if (sres3 != NULL)
            *sres3 =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    /* Read the 'Kc3' variable */
    {
        if (kc3 != NULL)
            *kc3 =  _mbim_message_read_guint64 (message, offset);
        offset += 8;
    }

    /* Read the 'N' variable */
    {
        if (n != NULL)
            *n =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    return TRUE;
}
