
/* GENERATED CODE... DO NOT EDIT */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 *
 * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
 */


#include <string.h>

#include "mbim-qmi.h"
#include "mbim-message-private.h"
#include "mbim-enum-types.h"
#include "mbim-error-types.h"
#include "mbim-device.h"
#include "mbim-utils.h"

/*****************************************************************************/
/* Message (Set): MBIM Message QMI msg */

/**
 * mbim_message_qmi_msg_set_new:
 * @qmi_msg_size: size of the qmi_msg array.
 * @qmi_msg: the 'QmiMsg' field, given as an array of #guint8 values.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'msg' set command in the 'QMI' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_qmi_msg_set_new (
    const guint32 qmi_msg_size,
    const guint8 *qmi_msg,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_QMI,
                                                 MBIM_CID_QMI_MSG,
                                                 MBIM_MESSAGE_COMMAND_TYPE_SET);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, FALSE, qmi_msg, qmi_msg_size);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message QMI msg */

/**
 * mbim_message_qmi_msg_response_parse:
 * @message: the #MbimMessage.
 * @qmux_size: return location for the size of the qmux array.
 * @qmux: return location for an array of #guint8 values. Do not free the returned value, it is owned by @message.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'QMUX' response command in the 'QMI' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_qmi_msg_response_parse (
    const MbimMessage *message,
    guint32 *qmux_size,
    const guint8 **qmux,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'QMUX' variable */
    {
        const guint8 *tmp;
        guint32 tmpsize;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, &tmpsize);
        if (qmux != NULL)
            *qmux = tmp;
        if (qmux_size != NULL)
            *qmux_size = tmpsize;
        offset += tmpsize;
    }

    return TRUE;
}
