
/* GENERATED CODE... DO NOT EDIT */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 *
 * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
 */


#include <string.h>

#include "mbim-stk.h"
#include "mbim-message-private.h"
#include "mbim-enum-types.h"
#include "mbim-error-types.h"
#include "mbim-device.h"
#include "mbim-utils.h"

/*****************************************************************************/
/* Message (Query): MBIM Message STK Pac */

/**
 * mbim_message_stk_pac_query_new:
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Pac' query command in the 'STK' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_stk_pac_query_new (
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_STK,
                                                 MBIM_CID_STK_PAC,
                                                 MBIM_MESSAGE_COMMAND_TYPE_QUERY);

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Set): MBIM Message STK Pac */

/**
 * mbim_message_stk_pac_set_new:
 * @pac_host_control: the 'PacHostControl' field, given as an array of 32 #guint8 values.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Pac' set command in the 'STK' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_stk_pac_set_new (
    const guint8 *pac_host_control,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_STK,
                                                 MBIM_CID_STK_PAC,
                                                 MBIM_MESSAGE_COMMAND_TYPE_SET);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, pac_host_control, 32);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message STK Pac */

/**
 * mbim_message_stk_pac_response_parse:
 * @message: the #MbimMessage.
 * @pac_support: return location for an array of 256 #guint8 values. Do not free the returned value, it is owned by @message.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'PacSupport' response command in the 'STK' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_stk_pac_response_parse (
    const MbimMessage *message,
    const guint8 **pac_support,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'PacSupport' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (pac_support != NULL)
            *pac_support = tmp;
        offset += 256;
    }

    return TRUE;
}

/*****************************************************************************/
/* Message (Notification): MBIM Message STK Pac */

/**
 * mbim_message_stk_pac_notification_parse:
 * @message: the #MbimMessage.
 * @pac_type: return location for a #MbimStkPacType, or %NULL if the 'PacType' field is not needed.
 * @data_buffer_size: return location for the size of the data_buffer array.
 * @data_buffer: return location for an array of #guint8 values. Do not free the returned value, it is owned by @message.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'DataBuffer' notification command in the 'STK' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_stk_pac_notification_parse (
    const MbimMessage *message,
    MbimStkPacType *pac_type,
    guint32 *data_buffer_size,
    const guint8 **data_buffer,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_INDICATE_STATUS) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a notification");
        return FALSE;
    }

    /* Read the 'PacType' variable */
    {
        if (pac_type != NULL)
            *pac_type =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    /* Read the 'DataBuffer' variable */
    {
        const guint8 *tmp;
        guint32 tmpsize;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, &tmpsize);
        if (data_buffer != NULL)
            *data_buffer = tmp;
        if (data_buffer_size != NULL)
            *data_buffer_size = tmpsize;
        offset += tmpsize;
    }

    return TRUE;
}

/*****************************************************************************/
/* Message (Set): MBIM Message STK Terminal Response */

/**
 * mbim_message_stk_terminal_response_set_new:
 * @response_size: size of the response array.
 * @response: the 'Response' field, given as an array of #guint8 values.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Terminal Response' set command in the 'STK' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_stk_terminal_response_set_new (
    const guint32 response_size,
    const guint8 *response,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_STK,
                                                 MBIM_CID_STK_TERMINAL_RESPONSE,
                                                 MBIM_MESSAGE_COMMAND_TYPE_SET);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, TRUE, TRUE, response, response_size);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message STK Terminal Response */

/**
 * mbim_message_stk_terminal_response_response_parse:
 * @message: the #MbimMessage.
 * @result_data_size: return location for the size of the result_data array.
 * @result_data: return location for an array of #guint8 values. Do not free the returned value, it is owned by @message.
 * @status_words: return location for a #guint32, or %NULL if the 'StatusWords' field is not needed.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'StatusWords' response command in the 'STK' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_stk_terminal_response_response_parse (
    const MbimMessage *message,
    guint32 *result_data_size,
    const guint8 **result_data,
    guint32 *status_words,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'ResultData' variable */
    {
        const guint8 *tmp;
        guint32 tmpsize;

        tmp = _mbim_message_read_byte_array (message, 0, offset, TRUE, TRUE, &tmpsize);
        if (result_data != NULL)
            *result_data = tmp;
        if (result_data_size != NULL)
            *result_data_size = tmpsize;
        offset += 8;
    }

    /* Read the 'StatusWords' variable */
    {
        if (status_words != NULL)
            *status_words =  _mbim_message_read_guint32 (message, offset);
        offset += 4;
    }

    return TRUE;
}

/*****************************************************************************/
/* Message (Query): MBIM Message STK Envelope */

/**
 * mbim_message_stk_envelope_query_new:
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Envelope' query command in the 'STK' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_stk_envelope_query_new (
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_STK,
                                                 MBIM_CID_STK_ENVELOPE,
                                                 MBIM_MESSAGE_COMMAND_TYPE_QUERY);

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Set): MBIM Message STK Envelope */

/**
 * mbim_message_stk_envelope_set_new:
 * @data_size: size of the data array.
 * @data: the 'Data' field, given as an array of #guint8 values.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'Envelope' set command in the 'STK' service.
 *
 * Returns: a newly allocated #MbimMessage, which should be freed with mbim_message_unref().
 */
MbimMessage *
mbim_message_stk_envelope_set_new (
    const guint32 data_size,
    const guint8 *data,
    GError **error)
{
    MbimMessageCommandBuilder *builder;

    builder = _mbim_message_command_builder_new (0,
                                                 MBIM_SERVICE_STK,
                                                 MBIM_CID_STK_ENVELOPE,
                                                 MBIM_MESSAGE_COMMAND_TYPE_SET);
    {
        _mbim_message_command_builder_append_byte_array (builder, FALSE, FALSE, TRUE, data, data_size);
    }

    return _mbim_message_command_builder_complete (builder);
}

/*****************************************************************************/
/* Message (Response): MBIM Message STK Envelope */

/**
 * mbim_message_stk_envelope_response_parse:
 * @message: the #MbimMessage.
 * @envelope_support: return location for an array of 32 #guint8 values. Do not free the returned value, it is owned by @message.
 * @error: return location for error or %NULL.
 *
 * Create a new request for the 'EnvelopeSupport' response command in the 'STK' service.
 *
 * Returns: %TRUE if the message was correctly parsed, %FALSE if @error is set.
 */
gboolean
mbim_message_stk_envelope_response_parse (
    const MbimMessage *message,
    const guint8 **envelope_support,
    GError **error)
{
    guint32 offset = 0;

    if (mbim_message_get_message_type (message) != MBIM_MESSAGE_TYPE_COMMAND_DONE) {
        g_set_error (error,
                     MBIM_CORE_ERROR,
                     MBIM_CORE_ERROR_INVALID_MESSAGE,
                     "Message is not a response");
        return FALSE;
    }

    /* Read the 'EnvelopeSupport' variable */
    {
        const guint8 *tmp;

        tmp = _mbim_message_read_byte_array (message, 0, offset, FALSE, FALSE, NULL);
        if (envelope_support != NULL)
            *envelope_support = tmp;
        offset += 32;
    }

    return TRUE;
}
